import skippy.config

import json
import os

class Profile:
    @staticmethod
    def load():
        try:
            with open(os.path.join(skippy.config.PROPERTY_FOLDER, 'profile.json'), 'r') as f:
                profile = json.loads(f.read())
            
            return (profile['login'], profile['password'])
        except json.decoder.JSONDecodeError:
            return ('','')

    @staticmethod
    def save(login,password):
        data = {'login': login, 'password': password}
        profile = json.dumps(data)
        with open(os.path.join(skippy.config.PROPERTY_FOLDER, 'profile.json'), 'w') as f:
            f.write(profile)


import os
import json

import skippy

version = skippy.__version__

SKIPPY_FOLDER = os.path.dirname(os.path.realpath(__file__))

ASSETS_FOLDER = os.path.join(SKIPPY_FOLDER, 'assets')

PROPERTY_FOLDER = os.path.join(SKIPPY_FOLDER, 'property')

LOGS_FOLDER = os.path.join(SKIPPY_FOLDER, 'logs')

PLUGINS_FOLDER = os.path.join(SKIPPY_FOLDER, 'plugins')


import os
import logging
from datetime import date

import skippy.config

LOG_LEVELS = {
    'DEBUG': logging.DEBUG,
    'INFO': logging.INFO,
    'WARNING': logging.WARNING,
    'ERROR': logging.ERROR,
    'CRITICAL': logging.CRITICAL,
}

def get_logger(name):
    logger = logging.getLogger(name)
    logger.setLevel(logging.INFO)

    c_handler = logging.StreamHandler()
    f_handler = logging.FileHandler(
        os.path.join(skippy.config.LOGS_FOLDER, f"{str(date.today())}.log"),
        'w', 'utf-8')

    c_format = logging.Formatter(
        "%(asctime)s - %(levelname)s - %(message)s", "%Y-%m-%d %H:%M:%S"
    )
    f_format = logging.Formatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s", "%Y-%m-%d %H:%M:%S"
    )
    c_handler.setFormatter(c_format)
    f_handler.setFormatter(f_format)

    f_handler.setLevel(logging.DEBUG)

    logger.addHandler(c_handler)
    logger.addHandler(f_handler)

    return logger


log = get_logger('skippy')
